searchData={"items":[{"type":"module","title":"NervesTimeZones","doc":"Local time support for Nerves devices\n\nThe `nerves_time_zones` application provides support for local time on Nerves\ndevices. It does this by bundling a time zone database that's compatible with\nthe `zoneinfo` library and providing logic to set the local time zone with\nthe C runtime (and hence Erlang and Elixir).\n\nTo use, call `NervesTimeZones.set_time_zone/1` with the any IANA time zone\nname (e.g., `\"America/New_York\"`). The time zone will be persisted so you\nwon't need to set it again. It is safe to always set it on boot if your\nproject will always be located in one time zone.\n\nAfter this, calls to `NaiveDateTime.local_now/1` will return the local time.\nIf you would prefer `DateTime` struct, call\n`DateTime.now(NervesTimeZones.get_time_zone())`.\n\nIf running a non-BEAM program that is time zone aware, you may need to set\nenvironment variables for it to work right. See\n`NervesTimeZones.tz_environment/0` for the proper settings.","ref":"NervesTimeZones.html"},{"type":"function","title":"NervesTimeZones.get_time_zone/0","doc":"Return the current local time zone","ref":"NervesTimeZones.html#get_time_zone/0"},{"type":"function","title":"NervesTimeZones.reset_time_zone/0","doc":"Reset the time zone to the default\n\nThis cleans up any saved time zone information and reapplies the defaults.\nThe default time zone is \"Etc/UTC\", but this can be changed by adding\nsomething like the following to your `config.exs`:\n\n```\nconfig :nerves_time_zones, default_time_zone: \"Asia/Tokyo\"\n```","ref":"NervesTimeZones.html#reset_time_zone/0"},{"type":"function","title":"NervesTimeZones.set_time_zone/1","doc":"Set the local time zone\n\nOnly known time zone names can be set. Others will return an error.\n`\"Etc/UTC\"` should always be available.\n\nThis time zone will be persisted and restored after a reboot.","ref":"NervesTimeZones.html#set_time_zone/1"},{"type":"function","title":"NervesTimeZones.time_zones/0","doc":"Return all known time zones\n\nThis function scans the time zone database each time it's called. It's\nnot slow, but if you just need to verify whether a time zone exists,\ncall `valid_time_zone?/1` instead.","ref":"NervesTimeZones.html#time_zones/0"},{"type":"function","title":"NervesTimeZones.tz_environment/0","doc":"Return environment variables for running OS processes\n\nIf you're using `System.cmd/3` to start an OS process that is time zone\naware, call this to set the environment appropriately. For example,\n`System.cmd(\"my_program\", [], env: NervesTimeZones.tz_environment())`","ref":"NervesTimeZones.html#tz_environment/0"},{"type":"function","title":"NervesTimeZones.valid_time_zone?/1","doc":"Return whether a time zone is valid","ref":"NervesTimeZones.html#valid_time_zone?/1"},{"type":"extras","title":"NervesTimeZones","doc":"# NervesTimeZones\n\n[![Hex version](https://img.shields.io/hexpm/v/nerves_time_zones.svg \"Hex version\")](https://hex.pm/packages/nerves_time_zones)\n[![CircleCI](https://circleci.com/gh/nerves-time/nerves_time_zones.svg?style=svg)](https://circleci.com/gh/nerves-time/nerves_time_zones)\n\nLocal time and time zones for Nerves devices\n\nNervesTimeZones provides a way of managing local time on embedded devices. It\nprovides the following:\n\n1. Set your time zone and have it be used for local time calls like\n   `NaiveDateTime.local_now/0`. The time zone persists across reboots.\n2. Set up Elixir's [Calendar time zone\n   database](https://hexdocs.pm/elixir/Calendar.html) using\n   [`zoneinfo`](https://hex.pm/packages/zoneinfo)\n3. Provide a small time zone database appropriate for many embedded devices\n\nIt does not support the automatic update of the time zone database like\n[tzdata](https://hex.pm/packages/tzdata) and [tz](https://hex.pm/packages/tz).\nFor now, you'll need to watch for new versions of the `nerves_time_zones`\npackage. (We're open to changing this, but it's not as easy as regularly polling\nIANA.)\n\nThe primary motivation for creating this library was to reduce the size of the\ntime zone database. `tzdata` and `tz` both work by compiling the IANA database\nto an internal format. At the time, `tzdata` compiled to a 3.5 MB ets table\n(~600 KB gzip compressed) and `tz` compiled to a 300 KB beam file (~250 KB gzip\ncompressed). Using TZif files (the `/usr/share/zoneinfo` ones) and 10 years of\ntime zone records for all time zones resulted in about 450 KB of data (~16 KB\ngzip compressed).","ref":"readme.html"},{"type":"extras","title":"Installation - NervesTimeZones","doc":"First, add `nerves_time_zones` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nerves_time_zones, \"~> 0.3.2\"}\n  ]\nend\n```\n\nNervesTimeZones persists the currently selected local time zone to\n`\"/data/nerves_time_zones\"`. This works well on Nerves devices. If you're\ndeveloping on your laptop, you may want to change the location by adding the\nfollowing in your project's `config.exs`:\n\n```elixir\nconfig :nerves_time_zones, data_dir: \"./tmp/nerves_time_zones\"\n```\n\nThe fetched IANA timezone db version defaults to `2022g`, which can be adjusted\nlike this:\n\n```elixir\nconfig :nerves_time_zones, version: \"2025a\"\n```\n\nThe default time zone is \"Etc/UTC\". If you want it to be something else, set it\nin the config like this:\n\n```elixir\nconfig :nerves_time_zones, default_time_zone: \"Europe/Paris\"\n```\n\nNervesTimeZones maintains only a subset of the available timezone database information\nto save on file size. The default keeps `[2022-01-01, +10 years]` relative to the\ndate of compilation. Both ends can be adjusted in the config like this:\n\n```elixir\nconfig :nerves_time_zones,\n  earliest_date: DateTime.to_unix(~U[2022-05-17 12:02:32Z]),\n  latest_date: System.os_time(:second) + 5 * 365 * 86400\n```","ref":"readme.html#installation"},{"type":"extras","title":"Database example - NervesTimeZones","doc":"If you just start up IEx, you may have seen something like this:\n\n```elixir\niex> DateTime.now(\"America/New_York\")\n{:error, :utc_only_time_zone_database}\n```\n\n`NervesTimeZones` automatically sets up the time zone database so once you've\nadded the `:nerves_time_zones` dependency, you'll get this instead:\n\n```elixir\niex> DateTime.now(\"America/New_York\")\n{:ok, #DateTime<2021-03-11 10:19:59.811175-05:00 EST America/New_York>}\n```\n\n`NervesTimeZones` is opinionated on the time zone database provider so it forces\nthe default and will log messages if there's a conflict with `tzdata` or `tz`.\nYou can still use those time zone databases if you really want them even though\nit defeats the purpose of keeping one database on a device. You'll just need to\nmanually specify the database in all of your `DateTime` calls.","ref":"readme.html#database-example"},{"type":"extras","title":"Local time example - NervesTimeZones","doc":"By default with `NervesTimeZones`, local time will be UTC. You can see this by\nrunning `NaiveDateTime.local_now/1`. Be aware that this behavior is different\nfrom the normal behavior of using your system's local time zone setting if you\ntrying this out on your laptop. Nerves devices don't have time zone settings by\ndefault.\n\n```elixir\niex> DateTime.utc_now\n~U[2021-03-11 15:10:41.573579Z]\niex> NaiveDateTime.local_now\n~N[2021-03-11 15:10:44]\n```\n\nYou can set the time zone like this (note the time shift by 5 hours):\n\n```elixir\niex> NervesTimeZones.set_time_zone(\"America/New_York\")\n:ok\niex> NaiveDateTime.local_now\n~N[2021-03-11 10:11:02]\n```","ref":"readme.html#local-time-example"},{"type":"extras","title":"Running OS commands - NervesTimeZones","doc":"It's possible to use the same time zone database with non-BEAM programs. For\nexample, on my system the default for C programs is Eastern time:\n\n```elixir\niex> System.cmd(\"date\", [])\n{\"Thu 11 Mar 2021 10:34:14 AM EST\\n\", 0}\n```\n\nOn a Nerves device, this would be UTC, but the concept is the same.\n\nSay I want it to be Hawaii time:\n\n```elixir\niex> NervesTimeZones.set_time_zone(\"Pacific/Honolulu\")\n:ok\n```\n\nThis won't affect the `date` program since it's not running on the BEAM. All is\nnot lost. `NervesTimeZones` can provide environment settings so that the C\nruntime will use the same data base and time zone setting as on the BEAM:\n\n```elixir\niex> System.cmd(\"date\", [], env: NervesTimeZones.tz_environment())\n{\"Thu 11 Mar 2021 05:40:38 AM HST\\n\", 0}\niex)> NaiveDateTime.local_now\n~N[2021-03-11 05:40:49]\n```","ref":"readme.html#running-os-commands"},{"type":"extras","title":"How it works - NervesTimeZones","doc":"NervesTimeZones pulls data from the [IANA time zone\ndatabase](http://www.iana.org/time-zones) and compiles it to TZif files using\n[zic(8)](https://data.iana.org/time-zones/tzdb/zic.8.txt). This is the same\nprocess used to create the files under `/usr/share/zoneinfo`. The difference is\nthat those contain time period records 50 years or more in the past and over 15\nyears to the future. NervesTimeZones limits the range substantially to reduce\nthe database size.\n\nSince the main embedded use cases for time zone information are to show the time\nand schedule events in the local time, having past time zone information is not\nneeded. This saves a ton of space, since time zones changed a lot in the 20th\ncentury.\n\nThe second part of the library is a NIF that updates the C runtime's local time\nzone setting. This setting also affects Erlang's and Elixir's local time\nfunctions like `NaiveDateTime.local_now/0` as well. The NIF is trivially short\nand calls [`tzset(3)`](https://man7.org/linux/man-pages/man3/tzset.3.html) with\nthe TZif file. Unfortunately, the way to pass the time zone is via the `TZ`\nenvironment variable, so if `TZ` previously pointed to anything before this\nlibrary runs, it won't afterwards.","ref":"readme.html#how-it-works"},{"type":"extras","title":"License - NervesTimeZones","doc":"Copyright (C) 2021 Frank Hunleth\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.3.6 - Changelog","doc":"* Fixes\n  * Support building against Erlang installs with spaces in paths\n\n* Updates\n  * Update the IANA database to 2024b\n  * Update tzcode from 2023c to 2024b version (many POSIX compatibility related updates)","ref":"changelog.html#v0-3-6"},{"type":"extras","title":"v0.3.5 - Changelog","doc":"* Updates\n  * Include backwards compatibility time zones. Based on feedback, these are in\n    such wide use that it's unexpected when they don't exist. This increases the\n    amount of data saved, but if you're using a deduplicating filesystem like\n    SquashFS with Nerves, it's very minimal.","ref":"changelog.html#v0-3-5"},{"type":"extras","title":"v0.3.4 - Changelog","doc":"* Updates\n  * Update the IANA database to 2024a\n  * Use the `:sync` flag when persisting time zone setting updates to avoid them\n    getting lost due to removing the power before the filesystem has been\n    written.","ref":"changelog.html#v0-3-4"},{"type":"extras","title":"v0.3.3 - Changelog","doc":"* Updates\n  * Update the IANA database to 2023c\n  * Update cached tzcode to 2023c to fix compilation errors with GCC 13.2","ref":"changelog.html#v0-3-3"},{"type":"extras","title":"v0.3.2 - Changelog","doc":"* Updates\n  * Update the IANA database to 2023a","ref":"changelog.html#v0-3-2"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"* Fixes\n  * Some build machines incorrectly detected gettext support when building zic.\n    Since gettext isn't needed, force it off to avoid the possibility of a build\n    error.","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"This release changes how dates are returned that happen before the earliest date\nin the time zone database. This is due to an update to IANA's zic compiler.\nPreviously the earliest time zone would be extended to dates before the\nbeginning of the database. This was wrong, though, since there could be any\nnumber of time zone changes. The new way is to return UTC and the unknown time\nzone, `-00`.\n\nIf you have dates in your regression tests, you probably will need to update\nthem if they're processed by nerves_time_zones.\n\n* Updates\n  * Update the IANA database and zic compiler to 2022g\n  * Fix the earliest database date to 2022/1/1 so regression tests can have\n    fixed dates without breaking independent of a nerves_time_zones version bump.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Updates\n  * Update the IANA database to 2022e","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Updates\n  * Update the IANA database to 2022b","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Added\n  * IANA database version, earliest date, and latest date now configurable form\n    the application environment (thanks @LostKobrakai)\n\n* Updates\n  * Update the IANA database to 2022a","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.10 - Changelog","doc":"* Updates\n  * Update the IANA database to 2021e (Palestine DST change date)","ref":"changelog.html#v0-1-10"},{"type":"extras","title":"v0.1.9 - Changelog","doc":"* Updates\n  * Update the IANA database to 2021d (Fiji!)","ref":"changelog.html#v0-1-9"},{"type":"extras","title":"v0.1.8 - Changelog","doc":"* Updates\n  * Update the IANA database to 2021c (reverts the time zone removals in 2021b)","ref":"changelog.html#v0-1-8"},{"type":"extras","title":"v0.1.7 - Changelog","doc":"* Updates\n  * Update the IANA database to 2021b","ref":"changelog.html#v0-1-7"},{"type":"extras","title":"v0.1.6 - Changelog","doc":"* Improvements\n  * Switch from `wget` to `curl` for database download to be friendlier to MacOS\n    users\n  * Cleanup and reduce Makefile prints","ref":"changelog.html#v0-1-6"},{"type":"extras","title":"v0.1.5 - Changelog","doc":"* Bug fixes\n  * Fix Makefile to support cross-compilation on Mac.","ref":"changelog.html#v0-1-5"},{"type":"extras","title":"v0.1.4 - Changelog","doc":"* Bug fixes\n  * Setting the default time zone didn't work on Nerves. Thanks to @pojiro for\n    fixing this.","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Updates\n  * Update the IANA database to 2021a\n  * Add GitHub action to check for IANA database updates and automatically send\n    a PR. Thanks to Connor Rigby for huge time saver.","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* New features\n  * Support changing the default time zone to something besides `\"Etc/UTC\"`","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Bug fixes\n  * Add files that were missing from the hex package","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}